# Generated by Django 2.2.6 on 2019-10-23 14:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oauth_clients', '0005_clientparam'),
    ]

    operations = [
        migrations.AddField(
            model_name='accesstoken',
            name='scope',
            field=models.TextField(blank=True, default='', verbose_name='Scope'),
        ),
    ]
