# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2018-11-21 20:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oauth_clients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='client',
            name='scope',
            field=models.CharField(blank=True, default=b'read', max_length=255, verbose_name='Scope'),
        ),
    ]
