# Generated by Django 2.2.28 on 2025-10-13 06:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oauth_clients', '0006_accesstoken_scope'),
    ]

    operations = [
        migrations.AlterField(
            model_name='accesstoken',
            name='access_token',
            field=models.TextField(verbose_name='Access token'),
        ),
        migrations.AlterField(
            model_name='accesstoken',
            name='refresh_token',
            field=models.TextField(verbose_name='Refresh token'),
        ),
    ]
