{% extends "admin/change_form.html" %}

{% load i18n admin_urls %}

{% block submit_buttons_bottom %}
    {{ block.super }}
    <div class="submit-row">
        <input type="submit" value="{% trans 'Authorize client' %}" name="_authorize-client">
    </div>
{% endblock %}
