# Generated by Django 2.1.2 on 2018-11-26 21:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oauth_clients', '0002_client_scope'),
    ]

    operations = [
        migrations.AlterField(
            model_name='client',
            name='scope',
            field=models.CharField(blank=True, default='read', max_length=255, verbose_name='Scope'),
        ),
        migrations.AlterField(
            model_name='client',
            name='token_endpoint',
            field=models.URLField(blank=True, default='', max_length=255, verbose_name='Token endpoint'),
        ),
    ]
