# Generated by Django 2.2.6 on 2019-10-22 17:32

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('oauth_clients', '0004_auto_20181127_0314'),
    ]

    operations = [
        migrations.CreateModel(
            name='ClientParam',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=40, verbose_name='Name')),
                ('value', models.TextField(blank=True, default='', verbose_name='Value')),
                ('client', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='params', to='oauth_clients.Client', verbose_name='Client')),
            ],
            options={
                'verbose_name': 'Client param',
                'verbose_name_plural': 'Client params',
            },
        ),
    ]
