#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_dj-oauth-clients
------------

Tests for `dj-oauth-clients` models module.
"""

from django.test import TestCase

from oauth_clients import models


class TestOauth_clients(TestCase):

    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass
