# Generated by Django 2.1.2 on 2018-11-27 03:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oauth_clients', '0003_auto_20181126_2148'),
    ]

    operations = [
        migrations.AddField(
            model_name='accesstoken',
            name='user_id',
            field=models.CharField(blank=True, default='', max_length=255, verbose_name='User id'),
        ),
        migrations.AddField(
            model_name='accesstoken',
            name='username',
            field=models.CharField(blank=True, default='', max_length=255, verbose_name='Username'),
        ),
    ]
